# Load in libraries
library(data.table) 
library(tidyverse)
library(ggridges)
library(ggpubr)
library(reshape2)
library(RColorBrewer)
library(ggplot2)
library(VennDiagram)
library(viridis)
library(hrbrthemes)
library(gghalves)
library(ComplexHeatmap)

setwd("/data/projects/punim0586/lecook/chipseq-pipeline/dunnart/results_10M/macs2/")
K4_K27 <- fread("H3K4me3_overlap.narrowPeak", header=FALSE)
K4 <- fread("H3K4me3_only.narrowPeak", header=FALSE)
K27 <- fread("H3K27ac_only.narrowPeak", header=FALSE)

setwd("/data/projects/punim0586/lecook/chipseq-pipeline/mouse/results_10M/macs2/")

K4_K27.E10 <- fread("H3K4me3_and_H3K27ac_E10.5.narrowPeak")
K4_K27.E11<- fread("H3K4me3_and_H3K27ac_E11.5.narrowPeak")
K4_K27.E12<- fread("H3K4me3_and_H3K27ac_E12.5.narrowPeak")
K4_K27.E13<- fread("H3K4me3_and_H3K27ac_E13.5.narrowPeak")
K4_K27.E14<- fread("H3K4me3_and_H3K27ac_E14.5.narrowPeak")
K4_K27.E15<- fread("H3K4me3_and_H3K27ac_E15.5.narrowPeak")

K4.E10<- fread("H3K4me3_E10.5_only.narrowPeak")
K4.E11<- fread("H3K4me3_E11.5_only.narrowPeak")
K4.E12<- fread("H3K4me3_E12.5_only.narrowPeak")
K4.E13<- fread("H3K4me3_E13.5_only.narrowPeak")
K4.E14<- fread("H3K4me3_E14.5_only.narrowPeak")
K4.E15<- fread("H3K4me3_E15.5_only.narrowPeak")

K27.E10<- fread("H3K27ac_E10.5_only.narrowPeak")
K27.E11<- fread("H3K27ac_E11.5_only.narrowPeak")
K27.E12<- fread("H3K27ac_E12.5_only.narrowPeak")
K27.E13<- fread("H3K27ac_E13.5_only.narrowPeak")
K27.E14<- fread("H3K27ac_E14.5_only.narrowPeak")
K27.E15<- fread("H3K27ac_E15.5_only.narrowPeak")

K4_K27$mark <- "H3K4me3 and H3K27ac"
K4_K27.E10$mark<- "H3K4me3 and H3K27ac"
K4_K27.E11$mark<- "H3K4me3 and H3K27ac"
K4_K27.E12$mark<- "H3K4me3 and H3K27ac"
K4_K27.E13$mark<- "H3K4me3 and H3K27ac"
K4_K27.E14$mark<- "H3K4me3 and H3K27ac"
K4_K27.E15$mark<- "H3K4me3 and H3K27ac"

K4$mark <- "H3K4me3"
K4.E10$mark<- "H3K4me3"
K4.E11$mark<- "H3K4me3"
K4.E12$mark<- "H3K4me3"
K4.E13$mark<- "H3K4me3"
K4.E14$mark<- "H3K4me3"
K4.E15$mark<- "H3K4me3"

K27$mark <- "H3K27ac"
K27.E10$mark <- "H3K27ac"
K27.E11$mark <- "H3K27ac"
K27.E12$mark <- "H3K27ac"
K27.E13$mark <- "H3K27ac"
K27.E14$mark <- "H3K27ac"
K27.E15$mark <- "H3K27ac"

K4_K27$stage <- "P0"
K4_K27.E10$stage <- "E10.5"
K4_K27.E11$stage <- "E11.5"
K4_K27.E12$stage <- "E12.5"
K4_K27.E13$stage <- "E13.5"
K4_K27.E14$stage <- "E14.5"
K4_K27.E15$stage <- "E15.5"

K4$stage <- "P0"
K4.E10$stage <- "E10.5"
K4.E11$stage <- "E11.5"
K4.E12$stage <- "E12.5"
K4.E13$stage <- "E13.5"
K4.E14$stage <- "E14.5"
K4.E15$stage <- "E15.5"

K27$stage <- "P0"
K27.E10$stage <- "E10.5"
K27.E11$stage <- "E11.5"
K27.E12$stage <- "E12.5"
K27.E13$stage <- "E13.5"
K27.E14$stage <- "E14.5"
K27.E15$stage <- "E15.5"
combinedPeaks <- rbind(K4, K4.E10, K4.E11, K4.E12, K4.E13, K4.E14, K4.E15, K4_K27, K4_K27.E10, K4_K27.E11, K4_K27.E12, K4_K27.E13, K4_K27.E14, K4_K27.E15, K27, K27.E10, K27.E11, K27.E12, K27.E13, K27.E14, K27.E15)

## Plot stacked bar graph with number of peaks for each histone mark
tbl <- with(combinedPeaks, table(stage, mark))
data <- as.data.frame(tbl)
data <- ddply(data, .(mark), transform, pos = cumsum(Freq)-0.2*Freq)

pdf("consensus_peaks.pdf")
ggplot(data, aes(factor(stage), Freq, fill=mark, label=)) + 
    geom_bar(position=position_stack(reverse = TRUE), stat="identity") +
    scale_fill_manual(values = c("#FFD166",  "#264653", "#2A9D8F"))+
geom_text(data=subset(data,Freq != 0),aes(label=Freq, y=pos), size=3) + 
    theme_minimal() + ylab("Number of peaks") +
    xlab("")
dev.off()

## Peak lengths
setwd("/data/projects/punim0586/lecook/chipseq-pipeline/dunnart/results_10M/macs2/")
enhancers <- fread("dunnart_enhancer_peaks.narrowPeak", header=FALSE)
promoters <- fread("dunnart_promoter_peaks.narrowPeak", header=FALSE)

setwd("/data/projects/punim0586/lecook/chipseq-pipeline/mouse/results_10M/macs2/")

promoter.E10 <- fread("E10.5_promoter_peaks.narrowPeak")
promoter.E11<- fread("E11.5_promoter_peaks.narrowPeak")
promoter.E12<- fread("E12.5_promoter_peaks.narrowPeak")
promoter.E13<- fread("E13.5_promoter_peaks.narrowPeak")
promoter.E14<- fread("E14.5_promoter_peaks.narrowPeak")
promoter.E15<- fread("E15.5_promoter_peaks.narrowPeak")

enhancer.E10 <- fread("E10.5_enhancer_peaks.narrowPeak")
enhancer.E11<- fread("E11.5_enhancer_peaks.narrowPeak")
enhancer.E12<- fread("E12.5_enhancer_peaks.narrowPeak")
enhancer.E13<- fread("E13.5_enhancer_peaks.narrowPeak")
enhancer.E14<- fread("E14.5_enhancer_peaks.narrowPeak")
enhancer.E15<- fread("E15.5_enhancer_peaks.narrowPeak")

enhancers$cre <- "enhancer"
promoters$cre <- "promoter"

promoter.E10$cre <- "promoter"
promoter.E11$cre <- "promoter"
promoter.E12$cre <- "promoter"
promoter.E13$cre <- "promoter"
promoter.E14$cre <- "promoter"
promoter.E15$cre <- "promoter"

enhancer.E10$cre <- "enhancer"
enhancer.E11$cre <- "enhancer"
enhancer.E12$cre <- "enhancer"
enhancer.E13$cre <- "enhancer"
enhancer.E14$cre <- "enhancer"
enhancer.E15$cre <- "enhancer"

enhancers$stage <- "P0"
promoters$stage <- "P0"

promoter.E10$stage <- "E10.5"
promoter.E11$stage <- "E11.5"
promoter.E12$stage <- "E12.5"
promoter.E13$stage <- "E13.5"
promoter.E14$stage <- "E14.5"
promoter.E15$stage <- "E15.5"

enhancer.E10$stage <- "E10.5"
enhancer.E11$stage <- "E11.5"
enhancer.E12$stage <- "E12.5"
enhancer.E13$stage <- "E13.5"
enhancer.E14$stage <- "E14.5"
enhancer.E15$stage <- "E15.5"
fullPeaks <- rbind(enhancers, enhancer.E10, enhancer.E11, enhancer.E12, enhancer.E13, enhancer.E14, enhancer.E15, promoters, promoter.E10, promoter.E11, promoter.E12, promoter.E13, promoter.E14, promoter.E15)
fullPeaks$length <- (fullPeaks$V3 - fullPeaks$V2)
fullPeaks$lengthkb <- fullPeaks$length / 1000
promoter = dplyr::filter(fullPeaks, cre == "promoter")
enhancer = dplyr::filter(fullPeaks, cre == "enhancer")


level_order <- c('P0', 'E10.5', 'E11.5', 'E12.5', 'E13.5', 'E14.5', 'E15.5')
## Plot peak lengths
p <- ggplot(promoter, aes(factor(stage, level = level_order), y = log10(length))) + 
  geom_half_violin(aes(fill=factor(stage), color=factor(stage)),
    side = "r", 
    position = "dodge"
    )+
  geom_boxplot(aes(color=factor(stage)),
    width = .15, 
    outlier.shape = NA,
    #fill=c("#FCF8EC", "#FCF8EC", "#FCF8EC", "#FCF8EC", "#FCF8EC", "#FCF8EC", "#FCF8EC"),
    fill=c("#E4F3F1", "#E4F3F1", "#E4F3F1", "#E4F3F1", "#E4F3F1", "#E4F3F1", "#E4F3F1"),
    position = position_dodge(width=.1)
  ) + gghalves::geom_half_point(
    side = "l", 
    #color=c("#E9C46A","#E9C46A", "#E9C46A", "#E9C46A", "#E9C46A", "#E9C46A", "#E9C46A"),
    color=c("#2A9D8F","#2A9D8F","#2A9D8F","#2A9D8F","#2A9D8F","#2A9D8F","#2A9D8F"),
    range_scale = .2, 
    alpha = .2) + theme_bw() + xlab("") + ylab("Log 10 length") 
pdf("promoter_length.pdf", width=9, height = 8)
p +  
#scale_color_manual(values = c("#E9C46A","#E9C46A", "#E9C46A", "#E9C46A", "#E9C46A", "#E9C46A", "#E9C46A")) +
scale_color_manual(values = c("#2A9D8F", "#2A9D8F", "#2A9D8F", "#2A9D8F", "#2A9D8F", "#2A9D8F", "#2A9D8F")) +
#scale_fill_manual(values = c("#F1DAA2","#F1DAA2", "#F1DAA2", "#F1DAA2", "#F1DAA2", "#F1DAA2", "#F1DAA2"))
scale_fill_manual(values = c("#7AC2B9", "#7AC2B9", "#7AC2B9", "#7AC2B9", "#7AC2B9", "#7AC2B9", "#7AC2B9"))
dev.off()

"#E9C46A","#E9C46A","#264653","#2A9D8F", "#E9C46A","#264653","#2A9D8F"
"#F1DAA2","#F1DAA2","#AEBABF","#7AC2B9", "#F1DAA2","#AEBABF","#7AC2B9"
"#FCF8EC","#F5F6F7","#E4F3F1", "#FCF8EC","#F5F6F7","#E4F3F1"),
#F1DAA2

# Peak intensity (fold-change) for enhancer/promoters
p <- ggplot(enhancer, aes(factor(stage, level = level_order), y = log10(length))) + 
  geom_violin(aes(fill=factor(stage), color=factor(stage)), 
    position = "dodge"
    )+
  geom_boxplot(aes(color=factor(stage)),
    width = .15, 
    outlier.shape = NA,
    fill=c("#FCF8EC", "#FCF8EC", "#FCF8EC", "#FCF8EC", "#FCF8EC", "#FCF8EC", "#FCF8EC"),
    #fill=c("#E4F3F1", "#E4F3F1", "#E4F3F1", "#E4F3F1", "#E4F3F1", "#E4F3F1", "#E4F3F1"),
    position = position_dodge(width=.1), notch=TRUE
  )  + theme_bw() + xlab("") + ylab("Log 10 Peak Intensity") 
pdf("enhancer_length.pdf", width=9, height = 8)
p +  
scale_color_manual(values = c("#E9C46A","#E9C46A", "#E9C46A", "#E9C46A", "#E9C46A", "#E9C46A", "#E9C46A")) +
#scale_color_manual(values = c("#2A9D8F", "#2A9D8F", "#2A9D8F", "#2A9D8F", "#2A9D8F", "#2A9D8F", "#2A9D8F")) +
scale_fill_manual(values = c("#F1DAA2","#F1DAA2", "#F1DAA2", "#F1DAA2", "#F1DAA2", "#F1DAA2", "#F1DAA2"))
#scale_fill_manual(values = c("#7AC2B9", "#7AC2B9", "#7AC2B9", "#7AC2B9", "#7AC2B9", "#7AC2B9", "#7AC2B9"))
dev.off()


## density of peaks distance from TSS
setwd("/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation/consensus/enhancers/")
enhancers <- fread("dunnart_enhancer_annotation.txt")
enhancer.E10 <- fread("E10.5_enhancer_annotation.txt")
enhancer.E11<- fread("E11.5_enhancer_annotation.txt")
enhancer.E12<- fread("E12.5_enhancer_annotation.txt")
enhancer.E13<- fread("E13.5_enhancer_annotation.txt")
enhancer.E14<- fread("E14.5_enhancer_annotation.txt")
enhancer.E15<- fread("E15.5_enhancer_annotation.txt")

setwd("/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation/consensus/promoters/")
promoters <- fread("dunnart_promoter_annotation.txt")
promoter.E10 <- fread("E10.5_promoter_annotation.txt")
promoter.E11<- fread("E11.5_promoter_annotation.txt")
promoter.E12<- fread("E12.5_promoter_annotation.txt")
promoter.E13<- fread("E13.5_promoter_annotation.txt")
promoter.E14<- fread("E14.5_promoter_annotation.txt")
promoter.E15<- fread("E15.5_promoter_annotation.txt")

enhancers$cre <- "enhancer"
promoters$cre <- "promoter"

promoter.E10$cre <- "promoter"
promoter.E11$cre <- "promoter"
promoter.E12$cre <- "promoter"
promoter.E13$cre <- "promoter"
promoter.E14$cre <- "promoter"
promoter.E15$cre <- "promoter"

enhancer.E10$cre <- "enhancer"
enhancer.E11$cre <- "enhancer"
enhancer.E12$cre <- "enhancer"
enhancer.E13$cre <- "enhancer"
enhancer.E14$cre <- "enhancer"
enhancer.E15$cre <- "enhancer"

enhancers$stage <- "P0"
promoters$stage <- "P0"

promoter.E10$stage <- "E10.5"
promoter.E11$stage <- "E11.5"
promoter.E12$stage <- "E12.5"
promoter.E13$stage <- "E13.5"
promoter.E14$stage <- "E14.5"
promoter.E15$stage <- "E15.5"

enhancer.E10$stage <- "E10.5"
enhancer.E11$stage <- "E11.5"
enhancer.E12$stage <- "E12.5"
enhancer.E13$stage <- "E13.5"
enhancer.E14$stage <- "E14.5"
enhancer.E15$stage <- "E15.5"

enhancer <- rbind(enhancers, enhancer.E10,enhancer.E11, enhancer.E12, enhancer.E13, enhancer.E14, enhancer.E15)
promoter <- rbind(promoters, promoter.E10, promoter.E11, promoter.E12, promoter.E13, promoter.E14, promoter.E15)
enhancer = enhancer[,log10_abs_dist:=log10(abs(distanceToTSS)+1)][,log10_abs_dist:=ifelse(distanceToTSS<0,-log10_abs_dist,log10_abs_dist)]
promoter = promoter[,log10_abs_dist:=log10(abs(distanceToTSS)+1)][,log10_abs_dist:=ifelse(distanceToTSS<0,-log10_abs_dist,log10_abs_dist)]


pdf("test2.pdf", width=10, height = 7)
ggplot(promoter, aes(x=log10_abs_dist, color = stage, fill=stage)) + geom_density(alpha=0.3) + scale_y_continuous(labels = scales::percent) + scale_x_continuous(limits=c(-7, 7))  + theme_bw()
dev.off()

+ scale_color_manual(values = c("#E9C46A","#264653","#2A9D8F")) + scale_fill_manual(values = c("#E9C46A","#264653","#2A9D8F"))

enhancer <- fread("dunnart_enhancer_annotation.txt", sep="\t", quote="", header=TRUE)
promoter <- fread("dunnart_promoter_annotation.txt", sep="\t", quote="", header=TRUE)
enhancer$cre <- "enhancer"
promoter$cre <- "promoter"
peak <- rbind(promoter, enhancer) %>% as.data.table()
peak = peak[, distanceToTSS.abs:= abs(distanceToTSS)]
# peak = peak[,log10_abs_dist:=log10(abs(distanceToTSS)+1)][,log10_abs_dist:=ifelse(distanceToTSS<0,-log10_abs_dist,log10_abs_dist)]
# enhancer = enhancer[,log10_abs_dist:=log10(abs(distanceToTSS)+1)][,log10_abs_dist:=ifelse(distanceToTSS<0,-log10_abs_dist,log10_abs_dist)]
# promoter = promoter[,log10_abs_dist:=log10(abs(distanceToTSS)+1)][,log10_abs_dist:=ifelse(distanceToTSS<0,-log10_abs_dist,log10_abs_dist)]
# peak = peak[,log10_intensity:=log10(V7)]
# peak = peak[,log10_length:=log10(width)]

pdf("test.pdf", width=10, height = 7)
ggplot(promoter, aes(x=log10_abs_dist)) + geom_density(alpha=0.5, color="#2A9D8F", fill="#2A9D8F") + scale_y_continuous(limits=c(0,0.3), labels = scales::percent) + scale_x_continuous(limits=c(-7, 7)) + theme_bw()
dev.off()

pdf("test.pdf", width=10, height = 7)
ggplot(enhancer, aes(x=log10_abs_dist, y=log10_length)) + geom_density(alpha=0.5, color="#E9C46A", fill="#E9C46A") + scale_y_continuous(limits=c(0,0.3), labels = scales::percent) + scale_x_continuous(limits=c(-7, 7)) + theme_bw()
dev.off()

ggplot(peak, aes(abs(distanceToTSS), y=log10_intensity, color=cre)) + geom_point(alpha=0.3) +  theme_bw() + scale_color_manual(values=c("#F1DAA2", "#7AC2B9"))
dev.off()
# peak length vs distance from TSS and peak intensity vs distance from TSS
pdf("peakIntensityVsDist.pdf", width=10, height = 7)
p <- ggscatter(
  peak, x = "distanceToTSS", y = "width",
  color = "cre", palette = "jco", add="reg.line",
  conf.int = TRUE, # Add confidence interval
  cor.coef = TRUE, # Add correlation coefficient. see ?stat_cor
  cor.coeff.args = list(method = "pearson", label.x = 3, label.sep = "\n"), xlab = "Number of genes per scaffold",
  ylab = "Number of peaks per scaffold"
  ) +
  facet_wrap(~cre)
p + theme(panel.spacing = unit(2, "lines"), plot.margin = margin(2, 2, 2, 2, "cm"))
dev.off()

pdf("peakLengthVsDist.pdf", width=10, height = 7)
ggplot(peak, aes(abs(distanceToTSS), y=log10_length, color=cre)) + geom_point(alpha=0.3) +  theme_bw() + scale_color_manual(values=c("#F1DAA2", "#7AC2B9"))
dev.off()



## Peak intensity for distal enhancers marked by H3K4me3
# subset log10_abs_dist between 3.5 and 7 (3000bp and 10 million bps)
enhancer <- fread("dunnart_enhancer_annotation.txt", sep="\t", quote="", header=TRUE)
promoter <- fread("dunnart_promoter_annotation.txt", sep="\t", quote="", header=TRUE)
enhancer$cre <- "enhancer"
promoter$cre <- "promoter"
enhancer = enhancer[,log10_abs_dist:=log10(abs(distanceToTSS)+1)]
promoter = promoter[,log10_abs_dist:=log10(abs(distanceToTSS)+1)]

promoter.subset=subset(promoter, log10_abs_dist >= 3.5)
promoter = subset(promoter, log10_abs_dist <3.5)
promoter.subset$cre = "subset"
data = rbind(promoter, promoter.subset)
data = data[,log10_intensity:=log10(V7)]

p <- ggplot(data, aes(factor(cre), y = log10_intensity)) + 
  #geom_violin(aes(fill=factor(cre), color=factor(cre)),
   # position = "dodge"
   # )+
  geom_boxplot(aes(color=factor(cre)),
    outlier.shape = NA,
    width = .15, 
    notch = TRUE,
    fill=c("#FCF8EC","#E4F3F1"),
    position = position_dodge(width=.1)
  ) + theme_bw() + xlab("") + ylab("Peak intensity") 
pdf("distalH3K4me3PeakIntensity.pdf", width=9, height = 8)
p +  scale_color_manual(values = c("#E9C46A","#2A9D8F")) +
scale_fill_manual(values = c("#F1DAA2","#7AC2B9")) + stat_compare_means(method = "wilcox.test" )
dev.off()

res <- wilcox.test(V7 ~ cre, data = data,
                   exact = FALSE)
# number of peaks per gene
enhancer <- fread("dunnart_enhancer_annotation.txt", sep="\t", quote="", header=TRUE)
promoter <- fread("dunnart_promoter_annotation.txt", sep="\t", quote="", header=TRUE)
enhancer$cre <- "enhancer"
promoter$cre <- "promoter"
peak <- rbind(enhancer, promoter)
peak.counts <- peak %>% as.data.frame() %>% group_by(geneId, cre) %>%
    summarise(count = n(), .groups = 'drop') %>% as.data.table()
peak.counts = peak.counts[,log10_abs_dist:=log10(count)][,log10_abs_dist:=ifelse(count<0,-log10_abs_dist,log10_abs_dist)]
pick <- peak.counts %>% filter(count > 50)

p <- ggplot(peak.counts, aes(factor(cre), y = log10_abs_dist)) + 
  geom_violin(aes(fill=factor(cre), color=factor(cre))) +
  geom_boxplot(aes(color=factor(cre)),
    width = .15, 
    outlier.shape = NA,
    fill=c("#FCF8EC","#E4F3F1"),
    position = position_dodge(width=.1)
  )  +
  geom_text(data = pick, aes(factor(cre), log10_abs_dist), label = pick$geneId, check_overlap = TRUE, size=3, position = position_jitter(w = 0.3)) +
  theme_bw() + xlab("") + ylab("Log 10 number of peaks") 
pdf("numberPeaksPerGene.pdf", width=9, height = 8)
p +  scale_color_manual(values = c("#E9C46A","#2A9D8F")) +
scale_fill_manual(values = c("#F1DAA2","#7AC2B9"))
dev.off()

## gene length and number of peaks per gene
p <- ggplot(peak.counts, aes(x=log10_abs_length, y = log10(n))) + 
  geom_point()+ theme_bw() + xlab("Gene Length") + ylab("Log 10 number of peaks") 
pdf("numberPeaksvsGeneLength.pdf", width=9, height = 8)
p
dev.off()

## Motif Enrichment 
setwd("/data/projects/punim0586/lecook/chipseq-pipeline/dunnart/results/macs2/motifEnrichment/enhancers/")
enhancers <- read.csv("knownResults.txt", sep=",",header=TRUE, quote="")
enhancers <- enhancers[order(enhancers$Log_P.value),] %>% head(17)
enhancers <- enhancers[-c(8,14), ]  
enhancers <- enhancers %>% dplyr::select(Motif_Name, Log_P.value)
setwd("/data/projects/punim0586/lecook/chipseq-pipeline/dunnart/results/macs2/motifEnrichment/promoters/")
promoters <- read.csv("knownResults.txt", sep="\t")
promoters <- head(promoters, 15)
promoters <- promoters %>% dplyr::select(Motif.Name, Log.P.value)

matrix <- data.matrix(abs(promoters$Log.P.value))
rownames(matrix) = c('Nrf2','Bach1','NFE2L2','NF-E2','YY1','Bach2','Jun-AP1', 'Fosl2', 'LEP', 'MafK', 'Fra2', 'ETS', 'EKLF', 'Zfp281', 'E-box')

pdf('promoter_motifEnrichment.pdf',width=3,height = 7)
Heatmap(matrix, col=c('#e4f3f1', '#cae7e3', '#afdad5', '#95cec7', '#7ac2b9', '#5fb6ab', '#45a99d', '#2a9d8f'))
dev.off()
col=c('#e4f3f1', '#cae7e3', '#afdad5', '#95cec7', '#7ac2b9', '#5fb6ab', '#45a99d', '#2a9d8f')

col=c('#fcf8ec', '#f9f0da','#f7e9c7','#f4e2b4','#f1daa2','#eed38f','#eccb7d','#e9c46a')






