## Input: annotation files from annotation_10M.R 
## Output: peak metrics file for ALL peak files (mouse and dunnart)
## Can be used as input for downstream analyses. eg. PCA

library(dplyr)
library(tidyverse)
library(data.table)

setwd("/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation/")

peakData <- function(fileList, plot1, plot2, plot3, outFile, colnames){
  files =list.files(fileList, pattern= ".txt", full.names=T) # create list of files in directory
  files = as.list(files)
  data = lapply(files, function(x) read.table(x, header=TRUE, sep="\t", quote = "", na.strings=c("", "NA"))) # read in all files
  #data = lapply(data, function(x){ x$peakLength <- x$end - x$start;return(x)})
  data = lapply(data, function(x) x=setnames(x, old="geneId", new="mouseensembl", skip_absent=TRUE) %>% as.data.table())
  subset = lapply(data, function(x) x %>% dplyr::select(seqnames, start, end, width, V7, mouseensembl) %>% as.data.table()) #V7 or V5
  
  # split = lapply(subset, function(x) x %>% split(by="mouseensembl")) ## split by ENSEMBL ID
  # split = lapply(split, function(x) lapply(x, function(i) i=setorderv(i,c('start', 'end'),1))) ## order peaks on start stop coordinates
  # split = lapply(split, function(x) lapply(x, function(i) i=i[,distanceBetweenPeaks:=lead(start)-end])) ## find distance between peaks with the same nearest gene
  # df = lapply(split, function(x) rbindlist(x)) ## bind rows back together
  df = subset
  names(df) = c("dunnart", "E10.5", "E11.5", "E12.5", "E13.5", "E14.5", "E15.5") ## add names to the dataframes for plots
  
  # pdf(plot1) # plot peak length versus peak intensity
  # plot_lst = lapply(seq_along(df), function(i) 
  #           print(ggplot(df[[i]], aes(x=width, y=V5)) + 
  #           geom_point() + 
  #           theme(plot.title = element_text(hjust = 0.5)) +
  #           ggtitle(names(df)[i])))
  # dev.off()

  #df2 = lapply(df, function(x) x[complete.cases(x[ , 7]),]) ## remove rows with NAs in the distance between between column
  

  # pdf(plot2) # plot distribution of distances between peaks per gene
  # plot_lst = lapply(seq_along(df2), function(i) 
  #            print(ggplot(df2[[i]], aes(x=distanceBetweenPeaks)) + scale_x_continuous(trans="log10", name="Log10 distance between peaks") +
  #             geom_density() + ylim(c(0,0.6)) +
  #            theme(plot.title = element_text(hjust = 0.5)) +
  #            ggtitle(names(df2)[i])))
  # dev.off()

  df = lapply(df, function(x) transform(x, intensity.divBy.length = V7 / width))
  df = lapply(df, function(x) add_tally(x))
  # pdf(plot3) # plot distribution of peak intensity divided by length
  # plot_lst = lapply(seq_along(df), function(i) 
  #           print(ggplot(df[[i]], aes(x=intensity.divBy.length)) + #+ scale_x_continuous(trans="log10", name="density") +
  #           geom_density() + 
  #           theme(plot.title = element_text(hjust = 0.5)) +
  #           ggtitle(names(df)[i])))
  # dev.off()

  df = lapply(df, function(x) x %>% dplyr::select(mouseensembl, n, V7, width, intensity.divBy.length) %>% as.data.table())
  metrics = lapply(df, function(x) as.data.frame(x) %>% group_by(mouseensembl, n) %>%
    summarise(count = n(), peakLength.Sum = sum(width), intensitySum = sum(V7), intensityMedian = median(V7), intensityByLength.Median = median(intensity.divBy.length), 
    intensityMean = mean(V7), intensityByLength.Mean = mean(V7), .groups = 'drop') %>% as.data.table())
  metrics = lapply(metrics, function(x) transform(x, peakFraction = (count / n)*100) )
  merged <- metrics %>% purrr::reduce(full_join, by = "mouseensembl")  # join all dataframes by ensembl geneID
  colnames(merged) = colnames # update colnames
  merged[is.na(merged)]= 0
  write.table(merged, file=outFile, sep="\t", quote=F, row.names=F) 
}

# Import annotated peak files (for the dunnart this is the output file that has converted IDs to mouse ensembl)
peakData(fileList = "consensus/promoters/clustered/", colnames = c("geneId", "smiCra1.totalPeaks", "smiCra1.peak.count", "smiCra.peakLength.Sum", "smiCra.intensity.Sum",
           "smiCra1.intensity.Median", "smiCra1.intensityByLength.Median", "smiCra1.intensityMean", 
            "smiCra1.intensityByLength.Mean","smiCra1.peak.fraction", "mm10.E10.5.totalPeaks", "mm10.E10.5.peak.count", "mm10.E10.5.peakLength.Sum", "mm10.E10.5.intensity.Sum",
           "mm10.E10.5.intensity.Median",  "mm10.E10.5.intensityByLength.Median", "mm10.E10.5.intensityMean",
            "mm10.E10.5.intensityByLength.Mean", "mm10.E10.5.peak.fraction", "mm10.E11.5.totalPeaks",
            "mm10.E11.5.peak.count", "mm10.E11.5.peakLength.Sum", "mm10.E11.5.intensity.Sum",
           "mm10.E11.5.intensity.Median",  "mm10.E11.5.intensityByLength.Median", "mm10.E11.5.intensityMean",
            "mm10.E11.5.intensityByLength.Mean", "mm10.E11.5.peak.fraction",  "mm10.E12.5.totalPeaks",
            "mm10.E12.5.peak.count", "mm10.E12.5.peakLength.Sum", "mm10.E12.5.intensity.Sum",
           "mm10.E12.5.intensity.Median", "mm10.E12.5.intensityByLength.Median",  "mm10.E12.5.intensityMean",
            "mm10.E12.5.intensityByLength.Mean", "mm10.E12.5.peak.fraction", "mm10.E13.5.totalPeaks",
            "mm10.E13.5.peak.count", "mm10.E13.5.peakLength.Sum", "mm10.E13.5.intensity.Sum",
           "mm10.E13.5.intensity.Median",  "mm10.E13.5.intensityByLength.Median", "mm10.E13.5.intensityMean",
            "mm10.E13.5.intensityByLength.Mean",  "mm10.E13.5.peak.fraction", "mm10.E14.5.totalPeaks",
            "mm10.E14.5.peak.count", "mm10.E14.5.peakLength.Sum", "mm10.E14.5.intensity.Sum",
           "mm10.E14.5.intensity.Median", "mm10.E14.5.intensityByLength.Median",  "mm10.E14.5.intensityMean",
            "mm10.E14.5.intensityByLength.Mean", "mm10.E14.5.peak.fraction",  "mm10.E15.5.totalPeaks",
            "mm10.E15.5.peak.count", "mm10.E15.5.peakLength.Sum", "mm10.E15.5.intensity.Sum",
           "mm10.E15.5.intensity.Median",  "mm10.E15.5.intensityByLength.Median", "mm10.E15.5.intensityMean",
            "mm10.E15.5.intensityByLength.Mean", "mm10.E15.5.peak.fraction"), plot1="promoterPeakIntensityVsLength_clustered.pdf", plot2="promoterDistanceBetweenPeaksDensity_clustered.pdf",
            plot3="promoterPeakIntensityByLengthDensity_clustered.pdf", outFile = "promoterPeaksPerGene_clustered.txt")

peakData(fileList = "consensus/enhancers/annotation/", colnames = c("geneId", "smiCra1.totalPeaks", "smiCra1.peak.count", "smiCra.peakLength.Sum", "smiCra.intensity.Sum",
           "smiCra1.intensity.Median", "smiCra1.intensityByLength.Median", "smiCra1.intensityMean", 
            "smiCra1.intensityByLength.Mean","smiCra1.peak.fraction", "mm10.E10.5.totalPeaks", "mm10.E10.5.peak.count", "mm10.E10.5.peakLength.Sum", "mm10.E10.5.intensity.Sum",
           "mm10.E10.5.intensity.Median",  "mm10.E10.5.intensityByLength.Median", "mm10.E10.5.intensityMean",
            "mm10.E10.5.intensityByLength.Mean", "mm10.E10.5.peak.fraction", "mm10.E11.5.totalPeaks",
            "mm10.E11.5.peak.count", "mm10.E11.5.peakLength.Sum", "mm10.E11.5.intensity.Sum",
           "mm10.E11.5.intensity.Median",  "mm10.E11.5.intensityByLength.Median", "mm10.E11.5.intensityMean",
            "mm10.E11.5.intensityByLength.Mean", "mm10.E11.5.peak.fraction",  "mm10.E12.5.totalPeaks",
            "mm10.E12.5.peak.count", "mm10.E12.5.peakLength.Sum", "mm10.E12.5.intensity.Sum",
           "mm10.E12.5.intensity.Median", "mm10.E12.5.intensityByLength.Median",  "mm10.E12.5.intensityMean",
            "mm10.E12.5.intensityByLength.Mean", "mm10.E12.5.peak.fraction", "mm10.E13.5.totalPeaks",
            "mm10.E13.5.peak.count", "mm10.E13.5.peakLength.Sum", "mm10.E13.5.intensity.Sum",
           "mm10.E13.5.intensity.Median",  "mm10.E13.5.intensityByLength.Median", "mm10.E13.5.intensityMean",
            "mm10.E13.5.intensityByLength.Mean",  "mm10.E13.5.peak.fraction", "mm10.E14.5.totalPeaks",
            "mm10.E14.5.peak.count", "mm10.E14.5.peakLength.Sum", "mm10.E14.5.intensity.Sum",
           "mm10.E14.5.intensity.Median", "mm10.E14.5.intensityByLength.Median",  "mm10.E14.5.intensityMean",
            "mm10.E14.5.intensityByLength.Mean", "mm10.E14.5.peak.fraction",  "mm10.E15.5.totalPeaks",
            "mm10.E15.5.peak.count", "mm10.E15.5.peakLength.Sum", "mm10.E15.5.intensity.Sum",
           "mm10.E15.5.intensity.Median",  "mm10.E15.5.intensityByLength.Median", "mm10.E15.5.intensityMean",
            "mm10.E15.5.intensityByLength.Mean", "mm10.E15.5.peak.fraction"), plot1="enhancerPeakIntensityVsLength_subsample.pdf", plot2="enhancerDistanceBetweenPeaksDensity_subsample.pdf",
            plot3="enhancerPeakIntensityByLengthDensity_subsample.pdf", outFile = "enhancerPeaksPerGene_subsample.txt")
